@@ -280,7 +280,7 @@ class KolmogorovSmirnov(AlphaManagement, NDigitsManagement, PlotsManagement):
         return result(tabulated, alfa)
 
     # with tests, with text, with database, with docstring
-    def draw_critical_values(self, ax=None, export=None, extension=None, file_name=None, dpi=None, decimal_separator=None, local=None):
+    def draw_critical_values(self, ax=None, export=None, extension=None, file_name=None, dpi=None, decimal_separator=None):
         """Draw a plot with the Kolmogorov Smirnov *critical data* [1]_.
 
         Parameters
@@ -298,8 +298,6 @@ class KolmogorovSmirnov(AlphaManagement, NDigitsManagement, PlotsManagement):
             The figure pixel density. The default is ``None``, which results in a ``100 dpis`` picture. This parameter must be a number higher than zero.
         decimal_separator : ``str``, optional
             The decimal separator symbol used in the chart. It can be the dot (``None`` or ``'.'``) or the comma (``','``).
-        local : ``str``, optional
-            The alias for the desired locale. Only used if ``decimal_separator=','`` to set the matplolib's default locale. Its only function is to change the decimal separator symbol and should be changed only if the ``"pt_BR"`` option is not available.
 
 
         Returns
@@ -375,9 +373,11 @@ class KolmogorovSmirnov(AlphaManagement, NDigitsManagement, PlotsManagement):
 
         ## decimal_separator ##
         decimal_separator = self._get_default_decimal_separator(decimal_separator)
+        checkers._check_is_str(decimal_separator, "decimal_separator", self.language)
+        helpers._check_decimal_separator(decimal_separator, self.language)
 
         ## local ##
-        local = self._get_default_local(local)
+        # local = self._get_default_local(local)
 
         fk_id_function = management._query_func_id("draw_critical_values")
         messages = management._get_messages(fk_id_function, self.language)
@@ -386,7 +386,7 @@ class KolmogorovSmirnov(AlphaManagement, NDigitsManagement, PlotsManagement):
         ### The values tabled in a dictionary ###
         kolmogorov_smirnov = KolmogorovSmirnov.KOLMOGOROV_SMIRNOV_TABLE
 
-        default_locale = helpers._change_locale(self.language, decimal_separator, local)
+        # default_locale = helpers._change_locale(self.language, decimal_separator, local)
 
         ### Make the plot ###
         if ax is None:
@@ -405,18 +405,22 @@ class KolmogorovSmirnov(AlphaManagement, NDigitsManagement, PlotsManagement):
         axes.set_ylabel(messages[4][0][0])
         axes.set_xticks([2, 5, 10, 15, 20, 25, 30, 35])
 
+        # decimal separator
+        if ax is None:
+            axes = helpers._change_decimal_separator_x_axis(fig, axes, decimal_separator)
+            axes = helpers._change_decimal_separator_y_axis(fig, axes, decimal_separator)
 
         ## If show equals True, display the graph ##
         if ax is None:
             fig.tight_layout()
             if export:
                 ### Baptism of Fire ###
-                file_name = helpers._check_conflicting_filename(file_name, extension, self.language)
+                exits, file_name = helpers._check_conflicting_filename(file_name, extension, self.language)
                 plt.savefig(file_name, dpi=dpi, bbox_inches='tight')
                 general._display_one_line_success(f"{messages[5][0][0]} '{file_name}' {messages[5][2][0]}")
             plt.show()
 
-        helpers._change_locale_back_to_default(default_locale)
+        # helpers._change_locale_back_to_default(default_locale)
 
         return axes
 
